import type { RenderOptions } from '../types';
export declare const defaultProps: Record<string, unknown>;
export declare abstract class Burger extends HTMLElement {
    static get observedAttributes(): string[];
    protected abstract get lines(): number;
    protected abstract render(options: RenderOptions): void;
    private _distance;
    private _easing;
    private _duration;
    private _pressed;
    private _size;
    private _updating;
    private _updatePromise;
    /**
     * A valid `transition-timing-function` CSS value, for example 'ease-out'.
     * @type {string}
     * @default cubic-bezier(0, 0, 0, 1)
     */
    get easing(): string;
    set easing(easing: string);
    /**
     * The vertical distance between the lines. Small (sm), medium (md) or large (lg).
     * @type {'sm' | 'md' | 'lg'}
     * @default md
     */
    get distance(): 'sm' | 'md' | 'lg';
    set distance(distance: 'sm' | 'md' | 'lg');
    /**
     * The duration of the animation. Can be set to zero if no animation is desired.
     * @type {number}
     * @default 0.4
     */
    get duration(): number;
    set duration(duration: number);
    /**
     * Set to true when element is pressed.
     * @type {boolean}
     * @default false
     */
    get pressed(): boolean;
    set pressed(pressed: boolean);
    /**
     * Size of the icon. Should be a number between 12 and 48.
     * @type {number}
     * @default 32
     */
    get size(): number;
    set size(size: number);
    constructor();
    connectedCallback(): void;
    attributeChangedCallback(prop: string, oldVal: string, newVal: string): void;
    handleEvent(event: KeyboardEvent | MouseEvent): void;
    protected getRenderOptions(): RenderOptions;
    protected update(): void;
    private _enqueueUpdate;
}
//# sourceMappingURL=burger.d.ts.map